@@ -40,8 +40,9 @@ versionNumber = '0.2.1' #version 0.2.1 added in HDF5 support
 
 #first define the standard run class type
 class DataRun:
-	def __init__(self, directory, runNumber, ignoreEventFile = False):
+	def __init__(self, directory, runNumber, ignoreEventFile = False, bulkRead = False):
 		self.ignoreEventFile = ignoreEventFile
+		self.bulkRead = bulkRead 
 		self.__hdf5 = False
 		self.__hdf5Files = []
 		self.__hdf5Filenames = []
@@ -155,10 +156,10 @@ class DataRun:
 	def __openTemperatureFiles(self): #open all of the temperature files and combine all that information
 		self.__temperatures = tmf.temperatureFile(self.__tmprtFilenames)
 	def __openWaveformFiles(self):
-		self.__coincFiles = wf.waveformFile(self.__coincFilenames, pixelMapping = self.parameterFile().BoardChannelPixelMap['pixel'])
-		self.__noiseFiles = wf.waveformFile(self.__noiseFilenames, pixelMapping = self.parameterFile().BoardChannelPixelMap['pixel'])
-		self.__pulsrFiles = wf.waveformFile(self.__pulsrFilenames, pixelMapping = self.parameterFile().BoardChannelPixelMap['pixel'])
-		self.__singlFiles = wf.waveformFile(self.__singlFilenames, pixelMapping = self.parameterFile().BoardChannelPixelMap['pixel'])
+		self.__coincFiles = wf.waveformFile(self.__coincFilenames, pixelMapping = self.parameterFile().BoardChannelPixelMap['pixel'], bulkRead = self.bulkRead)
+		self.__noiseFiles = wf.waveformFile(self.__noiseFilenames, pixelMapping = self.parameterFile().BoardChannelPixelMap['pixel'], bulkRead = self.bulkRead)
+		self.__pulsrFiles = wf.waveformFile(self.__pulsrFilenames, pixelMapping = self.parameterFile().BoardChannelPixelMap['pixel'], bulkRead = self.bulkRead)
+		self.__singlFiles = wf.waveformFile(self.__singlFilenames, pixelMapping = self.parameterFile().BoardChannelPixelMap['pixel'], bulkRead = self.bulkRead)
 	def __openEventFiles(self):
 		self.__eventFiles = []
 		for name in self.__eventFilenames:
