@@ -582,7 +582,7 @@ class waveformFile:
 					print('trap method takes 3-6 inputs: rise time, top length, decay rate, (threshold percent, mean, shift)')
 					return None
 				else:
-					eners, times = bf.applyTrapFilter(self.waves(prep=False), *params, pretrigger=pretrig, batchsize=batchsize, useGPU = useGPU, mean = mean, hdf5ChunkSize = self.hdf5ChunkSize, rechunk=rechunk, useFFTW = useFFTW)
+					eners, times = bf.applyTrapFilter(self.waves(prep=False), *params, pretrigger=pretrig, batchsize=batchsize, useGPU = useGPU, hdf5ChunkSize = self.hdf5ChunkSize, rechunk=rechunk, useFFTW = useFFTW)
 					headers = None
 					if self.headers() is not None:
 						headers = self.headers().copy()
@@ -595,7 +595,7 @@ class waveformFile:
 						pretrig = self.pretrigger - 100
 					else:
 						pretrig = 800
-				if len(params) != 2:
+				if not (len(params) >= 3 and len(params) <= 6):
 					print('cusp method takes 3-6 inputs: rise time, top length, decay rate, (threshold percent, mean, shift)')
 					return None
 				else:
